# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.0.0

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.storage as windows_storage

from winrt.windows.devices.portable import ServiceDeviceType

Self = typing.TypeVar('Self')

@typing.final
class ServiceDevice_Static(winrt._winrt.IInspectable_Static):
    # System.String Windows.Devices.Portable.ServiceDevice::GetDeviceSelector(Windows.Devices.Portable.ServiceDeviceType)
    def get_device_selector(cls, service_type: ServiceDeviceType, /) -> str: ...
    # System.String Windows.Devices.Portable.ServiceDevice::GetDeviceSelectorFromServiceId(System.Guid)
    def get_device_selector_from_service_id(cls, service_id: _uuid.UUID, /) -> str: ...

@typing.final
class ServiceDevice(winrt.system.Object, metaclass=ServiceDevice_Static):
    pass

@typing.final
class StorageDevice_Static(winrt._winrt.IInspectable_Static):
    # Windows.Storage.StorageFolder Windows.Devices.Portable.StorageDevice::FromId(System.String)
    def from_id(cls, device_id: str, /) -> windows_storage.StorageFolder: ...
    # System.String Windows.Devices.Portable.StorageDevice::GetDeviceSelector()
    def get_device_selector(cls) -> str: ...

@typing.final
class StorageDevice(winrt.system.Object, metaclass=StorageDevice_Static):
    pass

